==> qtbase-opensource-src_5.0.1+dfsg.orig.tar.xz: qtbase-opensource-src-5.0.1/src/tools/qdoc/tr.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the tools applications of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

/*
  tr.h
*/

#ifndef TR_H
#define TR_H

#ifndef QT_BOOTSTRAPPED
#  include "qcoreapplication.h"
#endif

#include <qstring.h>

QT_BEGIN_NAMESPACE

#if defined(QT_BOOTSTRAPPED) || defined(QT_NO_TRANSLATION)
inline QString tr(const char *sourceText, const char *comment = 0)
{
    Q_UNUSED(comment);
    return QString( QLatin1String(sourceText) );
}
#else
inline QString tr(const char *sourceText, const char *comment = 0)
{
    return QCoreApplication::instance()->translate("", sourceText, comment);
}
#endif

QT_END_NAMESPACE

#endif

==> qtbase-opensource-src_5.0.2+dfsg1.orig.tar.xz: qtbase-opensource-src-5.0.2+dfsg1/src/tools/qdoc/tr.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the tools applications of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

/*
  tr.h
*/

#ifndef TR_H
#define TR_H

#include <qglobal.h>

#if !defined(QT_BOOTSTRAPPED) && !defined(QT_NO_TRANSLATION)
#  define TRANSLATE_QDOC
#endif

#include <qstring.h>
#ifdef TRANSLATE_QDOC
#  include <qcoreapplication.h>
#endif

QT_BEGIN_NAMESPACE

#ifndef TRANSLATE_QDOC

#define Q_DECLARE_TR_FUNCTIONS(context)

inline QString tr(const char *sourceText, const char *comment = 0)
{
    Q_UNUSED(comment);
    return QString( QLatin1String(sourceText) );
}

struct QCoreApplication
{
    static inline QString translate(const char * /* context */ , const char *sourceText, const char * /* disambiguation */ = 0)
        { return QLatin1String(sourceText); }
};

#endif // !TRANSLATE_QDOC

QT_END_NAMESPACE

#endif
